from utils import get_data_from_excel


def find_plate():
    user_key = input("Please enter your key: ")
    data = get_data_from_excel()
    result = data.get(user_key, None)

    if result is not None:
        print(f'The owner of the car is: {result}')
    else:
        print('Owner NOT Found!!!')





from setuptools import setup, find_packages


# Setting up
setup(
    name="plateFinderOne",
    version='1.0.0',
    author="Guido Xhindoli",
    author_email="<mail@gmail.com>",
    description='A package find the plate',
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["openpyxl", "pandas", "pyarrow"],
    keywords=[ 'plateFinder', 'pythonsdaal', 'plate', 'sda', 'SDA'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)












